MKHybridMapConfiguration class final

Satellite imagery with roads and labels overlaid (MKHybridMapConfiguration). See: https://developer.apple.com/documentation/mapkit/mkhybridmapconfiguration

Inheritance

Constructors

MKHybridMapConfiguration({MKMapElevationStyle elevationStyle = .flat, MKPointOfInterestFilter pointOfInterestFilter = .includingAll, bool showsTraffic = false})
Creates a new MKHybridMapConfiguration object.
const

Properties

elevationStyle MKMapElevationStyle
Flat versus realistic 3-D terrain (MKMapConfiguration.elevationStyle).
finalinherited
hashCode int
The hash code for this object.
no setteroverride
pointOfInterestFilter MKPointOfInterestFilter
The pointOfInterestFilter property.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showsTraffic bool
The showsTraffic property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override