MKCoordinateSpan class final
The width and height of a map region in degrees, mirroring
MKCoordinateSpan(latitudeDelta:longitudeDelta:).
See: https://developer.apple.com/documentation/mapkit/mkcoordinatespan
- Annotations
Constructors
- MKCoordinateSpan({required double latitudeDelta, required double longitudeDelta})
-
Creates a new MKCoordinateSpan object.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- latitudeDelta → double
-
The latitudeDelta property.
final
- longitudeDelta → double
-
The longitudeDelta property.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override